TimeLog.PreLogPlug
(time_log v1.3.14)
This plug logs the incoming requests. It logs the IP address and has the ability to anonymize the IP address if set in config.
Summary
Functions
Call to PreLogPlug that initiates the request logging.
Initiates Response logging and logs the incoming request. Ensures that responses are only logged if the corresponding request was logged as well.
Functions
@spec call(Plug.Conn, Map) :: Plug.Conn
Call to PreLogPlug that initiates the request logging.
@spec initiate_logging(Plug.Conn) :: Plug.Conn
Initiates Response logging and logs the incoming request. Ensures that responses are only logged if the corresponding request was logged as well.